@@ -44,7 +44,8 @@ class CardBase:
                                     'context': {'card_css_class': 'card django-card',
                                                 'card_link_css_class': 'list-group-item cards-list-group-item',
                                                 'card_body_css_class': 'overflow-auto',
-                                                'card_body_css_style': 'height: calc(100vh - 150px);'}},
+                                                'card_body_css_style': 'height: calc(100vh - 150px);',
+                                                'modal': False}},
                  'tree_selection': {'name': 'cards/standard/tree_selection.html',
                                     'context': {'card_css_class': 'card django-card',
                                                 'card_body_css_class': 'card-body cards-list overflow-auto',
@@ -257,11 +258,14 @@ class CardBase:
         for result in results:
             if m2m_field is None:
                 value = result
+                html += html_barge.replace('%1%', str(value))
             else:
-                value = hasattr(result, m2m_field)
-                value = callable(value)
-            html += html_barge.replace('%1%', str(value))
-
+                if hasattr(result, m2m_field):
+                    value = getattr(result, m2m_field)
+                    if callable(value):
+                        value = value()
+                    html += html_barge.replace('%1%', str(value))
+                
         return self._add_entry_internal(label=label,
                                         value=html,
                                         default=default,
